"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeaturesController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const basePath = '/features';
let FeaturesController = class FeaturesController {
    constructor(featuresRepository) {
        this.featuresRepository = featuresRepository;
    }
    async create(features) {
        return this.featuresRepository.create(features);
    }
    async count(where) {
        return this.featuresRepository.count(where);
    }
    async find(filter) {
        return this.featuresRepository.find(filter);
    }
    async updateAll(features, where) {
        return this.featuresRepository.updateAll(features, where);
    }
    async findById(id, filter) {
        return this.featuresRepository.findById(id, filter);
    }
    async updateById(id, features) {
        await this.featuresRepository.updateById(id, features);
    }
    async replaceById(id, features) {
        await this.featuresRepository.replaceById(id, features);
    }
};
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.post(basePath),
    rest_1.response(200 /* OK */, {
        description: 'Features model instance',
        content: { 'application/json': { schema: rest_1.getModelSchemaRef(models_1.Features) } },
    }),
    tslib_1.__param(0, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Features, {
                    title: 'NewFeatures',
                }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.Features]),
    tslib_1.__metadata("design:returntype", Promise)
], FeaturesController.prototype, "create", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get(`${basePath}/count`),
    rest_1.response(200 /* OK */, {
        description: 'Features model count',
        content: { 'application/json': { schema: repository_1.CountSchema } },
    }),
    tslib_1.__param(0, rest_1.param.where(models_1.Features)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], FeaturesController.prototype, "count", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get(basePath),
    rest_1.response(200 /* OK */, {
        description: 'Array of Features model instances',
        content: {
            'application/json': {
                schema: {
                    type: 'array',
                    items: rest_1.getModelSchemaRef(models_1.Features, { includeRelations: true }),
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.filter(models_1.Features)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], FeaturesController.prototype, "find", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.patch(basePath),
    rest_1.response(200 /* OK */, {
        description: 'Features PATCH success count',
        content: { 'application/json': { schema: repository_1.CountSchema } },
    }),
    tslib_1.__param(0, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Features, { partial: true }),
            },
        },
    })),
    tslib_1.__param(1, rest_1.param.where(models_1.Features)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.Features, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], FeaturesController.prototype, "updateAll", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get(`${basePath}/{id}`),
    rest_1.response(200 /* OK */, {
        description: 'Features model instance',
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Features, { includeRelations: true }),
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.param.filter(models_1.Features, { exclude: 'where' })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], FeaturesController.prototype, "findById", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.patch(`${basePath}/{id}`),
    rest_1.response(204 /* NO_CONTENT */, {
        description: 'Features PATCH success',
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Features, { partial: true }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.Features]),
    tslib_1.__metadata("design:returntype", Promise)
], FeaturesController.prototype, "updateById", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.put(`${basePath}/{id}`),
    rest_1.response(204 /* NO_CONTENT */, {
        description: 'Features PUT success',
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.requestBody()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.Features]),
    tslib_1.__metadata("design:returntype", Promise)
], FeaturesController.prototype, "replaceById", null);
FeaturesController = tslib_1.__decorate([
    tslib_1.__param(0, repository_1.repository(repositories_1.FeaturesRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.FeaturesRepository])
], FeaturesController);
exports.FeaturesController = FeaturesController;
//# sourceMappingURL=features.controller.js.map