"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StrategiesController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const basePath = '/strategies';
let StrategiesController = class StrategiesController {
    constructor(strategiesRepository) {
        this.strategiesRepository = strategiesRepository;
    }
    async create(strategies) {
        return this.strategiesRepository.create(strategies);
    }
    async count(where) {
        return this.strategiesRepository.count(where);
    }
    async find(filter) {
        return this.strategiesRepository.find(filter);
    }
    async updateAll(strategies, where) {
        return this.strategiesRepository.updateAll(strategies, where);
    }
    async findById(id, filter) {
        return this.strategiesRepository.findById(id, filter);
    }
    async updateById(id, strategies) {
        await this.strategiesRepository.updateById(id, strategies);
    }
    async replaceById(id, strategies) {
        await this.strategiesRepository.replaceById(id, strategies);
    }
    async deleteById(id) {
        await this.strategiesRepository.deleteById(id);
    }
};
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.post(basePath),
    rest_1.response(200 /* OK */, {
        description: 'Strategies model instance',
        content: { 'application/json': { schema: rest_1.getModelSchemaRef(models_1.Strategies) } },
    }),
    tslib_1.__param(0, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Strategies, {
                    title: 'NewStrategies',
                }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.Strategies]),
    tslib_1.__metadata("design:returntype", Promise)
], StrategiesController.prototype, "create", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get(`${basePath}/count`),
    rest_1.response(200 /* OK */, {
        description: 'Strategies model count',
        content: { 'application/json': { schema: repository_1.CountSchema } },
    }),
    tslib_1.__param(0, rest_1.param.where(models_1.Strategies)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], StrategiesController.prototype, "count", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get(basePath),
    rest_1.response(200 /* OK */, {
        description: 'Array of Strategies model instances',
        content: {
            'application/json': {
                schema: {
                    type: 'array',
                    items: rest_1.getModelSchemaRef(models_1.Strategies, { includeRelations: true }),
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.filter(models_1.Strategies)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], StrategiesController.prototype, "find", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.patch(basePath),
    rest_1.response(200 /* OK */, {
        description: 'Strategies PATCH success count',
        content: { 'application/json': { schema: repository_1.CountSchema } },
    }),
    tslib_1.__param(0, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Strategies, { partial: true }),
            },
        },
    })),
    tslib_1.__param(1, rest_1.param.where(models_1.Strategies)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.Strategies, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], StrategiesController.prototype, "updateAll", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.get(`${basePath}/{id}`),
    rest_1.response(200 /* OK */, {
        description: 'Strategies model instance',
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Strategies, { includeRelations: true }),
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.param.filter(models_1.Strategies, { exclude: 'where' })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], StrategiesController.prototype, "findById", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.patch(`${basePath}/{id}`),
    rest_1.response(204 /* NO_CONTENT */, {
        description: 'Strategies PATCH success',
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.Strategies, { partial: true }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.Strategies]),
    tslib_1.__metadata("design:returntype", Promise)
], StrategiesController.prototype, "updateById", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.put(`${basePath}/{id}`),
    rest_1.response(204 /* NO_CONTENT */, {
        description: 'Strategies PUT success',
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.requestBody()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.Strategies]),
    tslib_1.__metadata("design:returntype", Promise)
], StrategiesController.prototype, "replaceById", null);
tslib_1.__decorate([
    loopback4_authentication_1.authenticate("bearer" /* BEARER */),
    loopback4_authorization_1.authorize({ permissions: ['*'] }),
    rest_1.del(`${basePath}/{id}`),
    rest_1.response(204 /* NO_CONTENT */, {
        description: 'Strategies DELETE success',
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String]),
    tslib_1.__metadata("design:returntype", Promise)
], StrategiesController.prototype, "deleteById", null);
StrategiesController = tslib_1.__decorate([
    tslib_1.__param(0, repository_1.repository(repositories_1.StrategiesRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.StrategiesRepository])
], StrategiesController);
exports.StrategiesController = StrategiesController;
//# sourceMappingURL=strategies.controller.js.map